@@ -120,10 +120,13 @@ ValidDataPrepStepType = Union[
     dto.SetColumnLevelStep,
     dto.SetColumnTypeStep,
     dto.SetTimeIndexStep,
+    dto.SimplifyCategoriesStep,
     dto.SplitColumnStep,
     dto.TransformTextStep,
 ]
 
+ParseOptions = Union[dto.CsvParseOptions, dto.ExcelParseOptions, dto.JsonParseOptions]
+
 
 # pylint: disable=too-many-public-methods
 class AnalyzeSwaggerClientWrapper:
@@ -139,7 +142,7 @@ class AnalyzeSwaggerClientWrapper:
         data: Union[pd.DataFrame, str, io.TextIOBase, io.BytesIO],
         name: str,
         description: Optional[str] = None,
-        parse_options: Optional[dto.ParseOptions] = None,
+        parse_options: Optional[ParseOptions] = None,
     ) -> int:
         with get_data_file(data) as data_file:
             response = create_file_data_set.sync_detailed(
@@ -164,7 +167,7 @@ class AnalyzeSwaggerClientWrapper:
         secret_key: str,
         bucket_name: str,
         path: str,
-        parse_options: Optional[dto.ParseOptions] = None,
+        parse_options: Optional[ParseOptions] = None,
     ) -> int:
         payload = dto.CreateCloudDataSetRequest(
             name=name,
@@ -190,7 +193,7 @@ class AnalyzeSwaggerClientWrapper:
         name: str,
         description: str,
         url: str,
-        parse_options: Optional[dto.ParseOptions] = None,
+        parse_options: Optional[ParseOptions] = None,
     ) -> int:
         payload = dto.CreateHttpDataSetRequest(
             name=name,
@@ -303,7 +306,7 @@ class AnalyzeSwaggerClientWrapper:
         return pd.read_parquet(stream)
 
     def delete_data_set(self, data_set_id: int) -> None:
-        delete_data_set.sync(client=self._client, id=data_set_id)
+        delete_data_set.sync_detailed(client=self._client, id=data_set_id)
 
     def apply_saved_data_preparation_steps(
         self,
@@ -374,7 +377,7 @@ class AnalyzeSwaggerClientWrapper:
         return check_exists(get_data_pipeline.sync(client=self._client, id=pipeline_id))
 
     def delete_data_pipeline(self, pipeline_id: int) -> None:
-        delete_data_pipeline.sync(client=self._client, id=pipeline_id)
+        delete_data_pipeline.sync_detailed(client=self._client, id=pipeline_id)
 
     def create_data_pipeline(self, data_set_id: int, name: str) -> int:
         payload = dto.DataPipelineCreateRequest(
@@ -408,7 +411,7 @@ class AnalyzeSwaggerClientWrapper:
         return check_exists(get_model.sync(client=self._client, id=model_id))
 
     def delete_model(self, model_id: int):
-        delete_model.sync(client=self._client, id=model_id)
+        delete_model.sync_detailed(client=self._client, id=model_id)
 
     # pylint: disable=too-many-arguments,too-many-locals
     def create_classification_model(
@@ -709,7 +712,7 @@ class AnalyzeSwaggerClientWrapper:
         )
 
     def stop_optimization(self, model_id: int):
-        stop_model.sync(client=self._client, id=model_id)
+        stop_model.sync_detailed(client=self._client, id=model_id)
 
     def download_model_results_as_csv(
         self,
@@ -861,7 +864,7 @@ class AnalyzeSwaggerClientWrapper:
         return pd.read_parquet(stream)
 
     def delete_prediction(self, prediction_id: int) -> None:
-        delete_prediction.sync(client=self._client, id=prediction_id)
+        delete_prediction.sync_detailed(client=self._client, id=prediction_id)
 
     def save_prediction_result_as_data_set(
         self, prediction_id: int, name: str, description: Optional[str] = None
@@ -961,7 +964,7 @@ class AnalyzeSwaggerClientWrapper:
             return pd.read_parquet(path=file)
 
     def delete_test(self, test_id: int) -> None:
-        delete_test.sync(client=self._client, id=test_id)
+        delete_test.sync_detailed(client=self._client, id=test_id)
 
     def save_test_result_as_data_set(
         self, test_id: int, name: str, description: Optional[str] = None
@@ -981,7 +984,7 @@ class AnalyzeSwaggerClientWrapper:
         )
 
     def delete_model_api(self, model_api_id: int) -> None:
-        delete_model_api.sync(client=self._client, model_api_id=model_api_id)
+        delete_model_api.sync_detailed(client=self._client, model_api_id=model_api_id)
 
     def create_model_api(
         self, model_id: int, name: str, description: Optional[str] = None
@@ -1035,7 +1038,7 @@ class AnalyzeSwaggerClientWrapper:
         )
 
     def delete_model_api_client(self, model_api_id: int, client_id: str) -> None:
-        delete_model_api_client.sync(
+        delete_model_api_client.sync_detailed(
             client=self._client, model_api_id=model_api_id, client_id=client_id
         )
 
@@ -1071,7 +1074,9 @@ class AnalyzeSwaggerClientWrapper:
         )
 
     def delete_pipeline_api(self, pipeline_api_id: int) -> None:
-        delete_pipeline_api.sync(client=self._client, pipeline_api_id=pipeline_api_id)
+        delete_pipeline_api.sync_detailed(
+            client=self._client, pipeline_api_id=pipeline_api_id
+        )
 
     def create_pipeline_api(
         self, pipeline_id: int, name: str, description: Optional[str] = None
@@ -1127,7 +1132,7 @@ class AnalyzeSwaggerClientWrapper:
         )
 
     def delete_pipeline_api_client(self, pipeline_api_id: int, client_id: str) -> None:
-        delete_pipeline_api_client.sync(
+        delete_pipeline_api_client.sync_detailed(
             client=self._client, pipeline_api_id=pipeline_api_id, client_id=client_id
         )
 
