@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Optional, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
@@ -9,23 +9,33 @@ T = TypeVar("T", bound="DeployedModelApiResponse")
 
 @attr.s(auto_attribs=True)
 class DeployedModelApiResponse:
-    """  """
+    """
+    Attributes:
+        id (int):
+        project_id (int):
+        name (str):
+        api_endpoint (str):
+        documentation_endpoint (str):
+        history (List[ApiHistoryResponse]):
+        description (Union[Unset, None, str]):
+    """
+
     id: int
     project_id: int
     name: str
     api_endpoint: str
     documentation_endpoint: str
     history: List[ApiHistoryResponse]
-    description: Union[Unset, Optional[str]] = UNSET
+    description: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
-        id =  self.id
-        project_id =  self.project_id
-        name =  self.name
-        api_endpoint =  self.api_endpoint
-        documentation_endpoint =  self.documentation_endpoint
+        id = self.id
+        project_id = self.project_id
+        name = self.name
+        api_endpoint = self.api_endpoint
+        documentation_endpoint = self.documentation_endpoint
         history = []
         for history_item_data in self.history:
             history_item = history_item_data.to_dict()
@@ -35,7 +45,7 @@ class DeployedModelApiResponse:
 
 
 
-        description =  self.description
+        description = self.description
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -52,6 +62,8 @@ class DeployedModelApiResponse:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
